@@ -2,9 +2,9 @@ from datetime import datetime
 from enum import Enum
 from typing import Any, Generic, Optional, TypeVar, List
 
-from pydantic import BaseModel, validator
+from pydantic import BaseModel
+from pydantic.functional_validators import field_validator
 from geojson_pydantic import Polygon
-from pydantic.generics import GenericModel
 
 # --- BASIC GEOMETRIES ---
 
@@ -29,13 +29,13 @@ class VendorNameEnum(str, Enum):
 
 
 class Provider(BaseModel):
-    provider_id: Optional[str]
+    provider_id: Optional[str] = None
     name: str
     description: str
 
 
 class Platform(BaseModel):
-    platform_id: Optional[str]
+    platform_id: Optional[str] = None
     provider_id: str
 
     name: str
@@ -43,8 +43,8 @@ class Platform(BaseModel):
 
     
 class Image(BaseModel):
-    image_id: Optional[str]
-    search_id: Optional[str]
+    image_id: Optional[str] = None
+    search_id: Optional[str] = None
     vendor_id: str
 
     platform_id: str
@@ -54,21 +54,21 @@ class Image(BaseModel):
 
     time: datetime
     polygon: Polygon
-    aoi_coverage: Optional[float]
+    aoi_coverage: Optional[float] = None
 
-    thumbnail: Optional[str]
+    thumbnail: Optional[str] = None
 
-    resolution: Optional[float]
-    cloud_cover: Optional[float]
-    off_nadir:   Optional[float]
+    resolution: Optional[float] = None
+    cloud_cover: Optional[float] = None
+    off_nadir:   Optional[float] = None
 
-    json_blob:   Optional[str]
+    json_blob:   Optional[str] = None
 
 
 class SavedLocationCreationRequest(BaseModel):
     location_footprint: Polygon
-    location_json: Any
-    location_osm: Optional[str]
+    location_json: Any = None
+    location_osm: Optional[str] = None
 
     name: str
     description: str
@@ -80,10 +80,10 @@ class SavedLocation(SavedLocationCreationRequest):
 
 
 class Asset(BaseModel):
-    asset_id: Optional[str]
+    asset_id: Optional[str] = None
     
-    image_id: Optional[str]
-    order_id: Optional[str]
+    image_id: Optional[str] = None
+    order_id: Optional[str] = None
 
     asset_name: str
     asset_size: int
@@ -106,17 +106,17 @@ class OrderStatusEnum(str, Enum):
     failed     = 'failed'
 
 class Order(BaseModel):
-    order_id: Optional[str]
-    image_id: Optional[str]
-    owner: Optional[str]
+    order_id: Optional[str] = None
+    image_id: Optional[str] = None
+    owner: Optional[str] = None
 
-    scene_id: Optional[str]
+    scene_id: Optional[str] = None
 
     purchase_date: datetime
 
     order_status: OrderStatusEnum
     price: int
-    json_blob: Optional[str]
+    json_blob: Optional[str] = None
 
 
 class OrderWithDetails(Order):
@@ -133,14 +133,17 @@ class APIError(BaseModel):
 
 
 DataT = TypeVar('DataT')
-class APIResponse(GenericModel, Generic[DataT]):
+class APIResponse(BaseModel, Generic[DataT]):
     data: Optional[DataT]
     error: Optional[str]
 
-    @validator('error', always=True)
-    def check_consistency(cls, v, values):
-        if v is not None and values['data'] is not None:
-            raise ValueError('must not provide both data and error')
-        if v is None and values.get('data') is None:
-            raise ValueError('must provide data or error')
-        return v
+    # do we really... need this?
+    # TODO[pydantic]: We couldn't refactor the `validator`, please replace it by `field_validator` manually.
+    # Check https://docs.pydantic.dev/dev-v2/migration/#changes-to-validators for more information.
+    # @field_validator('error')
+    # def check_consistency(cls, v, values):
+    #     if v is not None and values['data'] is not None:
+    #         raise ValueError('must not provide both data and error')
+    #     if v is None and not 'data' in values:
+    #         raise ValueError('must provide data or error')
+    #     return v
