@@ -7,5 +7,5 @@ class UserSignupForm(BaseModel):
     email: str
     password: str
 
-    invite_code: Optional[str]
+    invite_code: Optional[str] = None
 
