@@ -11,16 +11,16 @@ class APITierEnum(str, Enum):
 
 
 class APIKey(BaseModel):
-    key_id: Optional[str]
-    key_secret: Optional[str]
+    key_id: Optional[str] = None
+    key_secret: Optional[str] = None
 
     owner: str
     active: bool
     tier: APITierEnum
     created: datetime
 
-    notes: Optional[str]
-    internal: Optional[bool]
+    notes: Optional[str] = None
+    internal: Optional[bool] = None
 
 class APIKeyCreationRequest(BaseModel):
     tier: APITierEnum
