@@ -8,8 +8,8 @@ class UserProfile(BaseModel):
     email: str
     username: str
 
-    first_name: Optional[str]
-    last_name: Optional[str]
+    first_name: Optional[str] = None
+    last_name: Optional[str] = None
 
 
 class User(UserProfile):
@@ -18,7 +18,7 @@ class User(UserProfile):
     email_verified: bool
     disabled: bool
     
-    org_id: Optional[str]
+    org_id: Optional[str] = None
 
 
 class UserWithPassword(User):
@@ -31,7 +31,7 @@ class UserWithPassword(User):
         :return: User object
         :rtype: User
         """
-        return User.parse_obj(self.dict())
+        return User.model_validate(self.model_dump())
 
 
 class UserSession(BaseModel):
